# Changelog

## [0.1.2a1](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/tree/0.1.2a1) (2025-11-05)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/compare/0.1.1...0.1.2a1)

**Merged pull requests:**

- Update ovos-plugin-manager version range [\#9](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/pull/9) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
